@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: link_slv.c 3081 2006-11-19 17:01:56Z kevinkofler $ */
+/* $Id: link_slv.c 3723 2007-08-25 06:14:48Z roms $ */
 
 /*  libticables2 - link cable library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -27,18 +27,15 @@
 
 #ifndef NO_CABLE_SLV
 
-#if defined(__WIN32__)
-#include "win32/link_slv.c"
-
-#else
+#if defined(__WIN32__) && !defined(__MINGW32__)
+# define HAVE_LIBUSB
+#endif
 
 #ifdef HAVE_LIBUSB
-#include "linux/link_slv.c"
+# include "linux/link_slv.c"
 #endif
 #ifdef HAVE_LINUX_TICABLE_H
-#include "linux/link_dev.c"
-#endif
-
+# include "linux/link_dev.c"
 #endif
 
 #endif
