@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: link_xxx.c 3053 2006-11-06 17:08:45Z roms $ */
+/* $Id: link_xxx.c 3713 2007-08-10 02:14:13Z kevinkofler $ */
 
 /*  libticables2 - link cable library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -44,7 +44,7 @@ TIEXPORT1 int TICALL ticables_cable_open(CableHandle* handle)
 
 	TRYC(handle->cable->prepare(handle));
 
-	TRYC(cable->open(handle));
+	TRYC((cable->open)(handle));
 
 	handle->open = 1;
 	START_LOGGING(handle);
