@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: link_par.c 3084 2006-11-26 09:07:10Z roms $ */
+/* $Id: link_par.c 3720 2007-08-24 20:57:50Z roms $ */
 
 /*  libticables2 - link cable library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -51,7 +51,7 @@ static int par_prepare(CableHandle *h)
 	}
 
 	// detect stuffs
-	ret = check_for_parport(h->device);
+	ret = linux_check_parport(h->device);
 	if(ret)
 	{
 		free(h->device); h->device = NULL;
