@@ -57,7 +57,7 @@ static int ser_prepare(CableHandle *h)
     }
 
     // detect stuffs
-    ret = check_for_tty(h->device);
+    ret = linux_check_tty(h->device);
 	if(ret)
 	{
 		free(h->device); h->device = NULL;
