@@ -1,12 +1,13 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: link_slv.c 3081 2006-11-19 17:01:56Z kevinkofler $ */
+/* $Id: link_slv.c 3720 2007-08-24 20:57:50Z roms $ */
 
 /*  libticables2 - link cable library, a part of the TiLP project
- *  Copyright (C) 1999-2006  Romain Lievin
- *  Copyright (C) 2001 Julien Blache (original author)
+ *  Copyright (c) 1999-2006 Romain Lievin
+ *  Copyright (c) 2001 Julien Blache (original author)
  *  Portions lifted from libusb (LGPL):
  *  Copyright (c) 2000-2003 Johannes Erdfelt <johannes@erdfelt.com>
  *  Modifications for libticables Copyright (C) 2005 Kevin Kofler
+ *  Copyright (c) 2007 Romain Livin (libusb-win32 support)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -66,13 +67,34 @@
 #include <stdio.h>
 #include <string.h>
 #include <fcntl.h>
+#include <errno.h>
+
+#ifndef __WIN32__
+#include <unistd.h>
 #include <sys/time.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <unistd.h>
-#include <errno.h>
-#include <usb.h>
 #include <sys/ioctl.h>
+#endif
+
+#ifdef __WIN32__
+# include "../win32/usb.h"
+#else
+# include <usb.h>
+#endif
+
+/* --- */
+
+#ifdef __WIN32__	// found in src/error.h of libusb-win32
+# define ETIMEDOUT	-116
+//# define EPIPE	-117
+#endif
+
+#ifdef __WIN32
+# define usb_busses	usb_get_busses()
+#endif
+
+/* --- */
 
 #ifdef __LINUX__
 /* the libusb internal structure from usbi.h */
@@ -166,6 +188,8 @@ static int io_pending = 0;
 static struct usb_urb urb;
 #endif
 
+/* --- */
+
 #include "../ticables.h"
 #include "../logging.h"
 #include "../error.h"
@@ -178,9 +202,6 @@ static struct usb_urb urb;
 #define MAX_CABLES   4
 
 #define VID_TIGLUSB  0x0451     /* Texas Instruments, Inc.            */
-#define PID_TIGLUSB  0xE001     /* TI-GRAPH LINK USB (SilverLink)     */
-#define PID_TI89TM   0xE004     /* TI89 Titanium w/ embedded USB port */
-#define PID_TI84P    0xE008     /* TI84+ w/ embedded USB port         */
 
 #define TIGL_BULK_IN    0x81    /* IN  endpoint */
 #define TIGL_BULK_OUT   0x02    /* OUT endpoint */
@@ -203,9 +224,11 @@ typedef struct
 static usb_infos tigl_infos[] =
 {
         {0x0451, 0xe001, "TI-GRAPH LINK USB", NULL},
-        {0x0451, 0xe004, "TI-89 Titanium Calculator", NULL},
-        {0x0451, 0xe008, "TI-84 Plus Silver Calculator", NULL},
-        {}
+		{0x0451, 0xe003, "TT-84 Plus Hand-Held", NULL},
+        {0x0451, 0xe004, "TI-89 Titanium Hand-Held", NULL},
+        {0x0451, 0xe008, "TI-84 Plus Silver Hand-Held", NULL},
+		{0x0451, 0xe012, "TI-Nspire Hand-Held", NULL},
+        { 0 }
 };
 
 // list of devices found 
@@ -280,7 +303,7 @@ static int tigl_find(void)
 		{
 		    if(dev->descriptor.idProduct == tigl_infos[i].pid)
 		    {
-			ticables_info(" found <%s> on #%i, version <%x.%02x>",
+			ticables_info(" found %s on #%i, version <%x.%02x>",
 				      tigl_get_product(dev), j+1,
 				      dev->descriptor.bcdDevice >> 8,
 				      dev->descriptor.bcdDevice & 0xff);
@@ -427,7 +450,11 @@ static int slv_prepare(CableHandle *h)
 {
 	char str[64];
 
-	TRYC(check_for_libusb());
+#ifdef __WIN32__
+	TRYC(win32_check_libusb());
+#else
+	TRYC(linux_check_libusb());
+#endif
 
 	if(h->port >= MAX_CABLES)
 	    return ERR_ILLEGAL_ARG;
@@ -699,7 +726,7 @@ static int slv_get(CableHandle* h, uint8_t *data, uint32_t len)
 
     // we can't do that in any other way because slv_get_ can returns
     // 1, 2, ..., len bytes.
-    for(i = 0; i < len; i++)
+    for(i = 0; i < (int)len; i++)
 	TRYC(slv_get_(h, data+i));
     
     return 0;
@@ -729,7 +756,8 @@ static int raw_probe(CableHandle *h)
     for(i = 0; i < MAX_CABLES; i++)
     {
 	if(tigl_devices[h->address].pid == PID_TI89TM ||
-	   tigl_devices[h->address].pid == PID_TI84P)
+	   tigl_devices[h->address].pid == PID_TI84P ||
+	   tigl_devices[h->address].pid == PID_TI84P_SE)
 	    return 0;
     }    
 
