@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: probe.c 3060 2006-11-06 17:51:54Z roms $ */
+/* $Id: probe.c 3720 2007-08-24 20:57:50Z roms $ */
 
 /*  libticables2 - link cable library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -134,9 +134,9 @@ TIEXPORT1 int TICALL ticables_probing_finish(int ***result)
 TIEXPORT1 int TICALL ticables_is_usb_enabled(void)
 {
 #if defined(__WIN32__)
-	return win32_detect_tiglusb();
+	return !win32_check_libusb();
 #elif defined(__LINUX__) && defined(HAVE_LIBUSB)
-	return !check_for_libusb();
+	return !linux_check_libusb();
 #elif defined(HAVE_LIBUSB)
 	return 1;
 #else
@@ -166,7 +166,6 @@ TIEXPORT1 int TICALL ticables_get_usb_devices(int **list, int *len)
 	int ret = 0;
 
 	ret = usb_probe_devices(list);
-	printf("ret = %i\n", ret);
 	if(ret)
 	{
 	        *list = calloc(1, sizeof(int));
