@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: type2str.c 3053 2006-11-06 17:08:45Z roms $ */
+/* $Id: type2str.c 3249 2007-04-03 15:47:31Z roms $ */
 
 /*  libticables2 - link cable library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -42,7 +42,7 @@ TIEXPORT1 const char *TICALL ticables_model_to_string(CableModel model)
 	case CABLE_SLV: return "SilverLink";
 	case CABLE_USB: return "DirectLink";
 	case CABLE_VTI: return "VTi";
-	case CABLE_TIE: return "TiEmu";
+	case CABLE_TIE: return "TiEmu/TilEm";
 	case CABLE_VTL: return "virtual";
 	case CABLE_ILP: return "linkport";
 	case CABLE_DEV: return "UsbKernel";
@@ -76,6 +76,10 @@ TIEXPORT1 CableModel TICALL ticables_string_to_model(const char *str)
 		return CABLE_VTI;
 	else if(!strcmp(str, "TiEmu"))
 		return CABLE_TIE;
+	else if(!strcmp(str, "TilEm"))
+		return CABLE_TIE;
+	else if(!strcmp(str, "TiEmu/TilEm"))
+		return CABLE_TIE;
 	else if(!strcmp(str, "virtual"))
 		return CABLE_VTL;
 	else if(!strcmp(str, "linkport"))
