@@ -1,5 +1,5 @@
 /* Hey EMACS -*- win32-c -*- */
-/* $Id: detect.c 3053 2006-11-06 17:08:45Z roms $ */
+/* $Id: detect.c 3721 2007-08-24 21:22:35Z roms $ */
 
 /*  libticables2 - link cable library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -23,28 +23,34 @@
 
 #include <windows.h>
 
+#include "../error.h"
 #include "../logging.h"
 #include "detect.h"
-#include "porttalk.h"
+
+#include "../win32/dha.h"
+#include "../win64/rwp.h"
 
 #ifdef __MINGW32__
-#include "porttalk.c"
+#include "../win32/dha.c"
+#include "../win64/rwp.c"
 #endif
 
-int win32_detect_os(void)
+// Note: the kernel version of XP x64 is 5.2, like Windows 2003, not 5.1 as 
+// Windows XP 32-Bit.
+
+int win32_check_os(void)
 {
 	OSVERSIONINFO os;
+	SYSTEM_INFO si;
+
+	GetSystemInfo(&si);	// should use GetNativeSystemInfo(&si); & si.wProcessorArchitecture but MSVC too old
+	if(si.dwProcessorType > 586)
+		return WIN_64;
 
   	memset(&os, 0, sizeof(OSVERSIONINFO));
   	os.dwOSVersionInfoSize = sizeof(OSVERSIONINFO);
   	GetVersionEx(&os);
-	/*
-  	ticables_info("  operating System: %s",
-	  (os.dwPlatformId == VER_PLATFORM_WIN32_WINDOWS) ?
-	  "Windows9x" : "WindowsNT");
-  	ticables_info("  version: %i.%i\n",
-	  os.dwMajorVersion, os.dwMinorVersion);
-	*/
+
   	if (os.dwPlatformId == VER_PLATFORM_WIN32_WINDOWS)
 		return WIN_9X;
   	else if (os.dwPlatformId == VER_PLATFORM_WIN32_NT)
@@ -55,65 +61,44 @@ int win32_detect_os(void)
 	return 0;
 }
 
-int win32_detect_porttalk(void)
+int win32_check_dha(void)
 {
-	HANDLE PortTalk_Handle;	/* Handle for PortTalk Driver */
+#ifndef _WIN64
 	int result = 0;
 
-	PortTalk_Handle = CreateFile("\\\\.\\PortTalk",
-				   GENERIC_READ,
-				   0,
-				   NULL,
-				   OPEN_EXISTING,
-				   FILE_ATTRIBUTE_NORMAL, NULL);
+	dha_detect(&result);
 
-    if (PortTalk_Handle == INVALID_HANDLE_VALUE) 
-	{
-		// Start or Install PortTalk Driver
-		PortTalkStartDriver();
-
-		// Don't be too hurry !
-		Sleep(1000);
-
-		// Then try to open once more, before failing
-		PortTalk_Handle =
-			CreateFile("\\\\.\\PortTalk",
-				GENERIC_READ, 0, NULL,
-				OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, NULL);
-
-		if (PortTalk_Handle == INVALID_HANDLE_VALUE) 
-		{
-	  		ticables_info("PortTalk: Couldn't access PortTalk Driver, Please ensure driver is loaded.");
-	  		//return -1;
-		}
-    }
-
-    if (PortTalk_Handle != INVALID_HANDLE_VALUE) 
-	{
-		result = 1;
-		CloseHandle(PortTalk_Handle);
-    }
-
-	ticables_info("PorTalk%sfound.", result ? " " : " not ");
-
-	return result;
+	return result ? 0 : ERR_DHA_NOT_FOUND;
+#else
+	return 0;
+#endif
 }
 
-int win32_detect_tiglusb(void)
+int win32_check_rwp(void)
 {
-	HINSTANCE hDll = NULL;	/* Handle for TiglUsb driver */
+#ifdef _WIN64
 	int result = 0;
 
-	hDll = LoadLibrary("TiglUsb.DLL");
+	rwp_detect(&result);
+
+	return result ? 0: ERR_RWP_NOT_FOUND;
+#else
+	return 0;
+#endif
+}
+
+int win32_check_libusb(void)
+{
+	HINSTANCE hDll = NULL;	/* Handle for TiglUsb driver */
+	int ret = -1;
+
+	hDll = LoadLibrary("libusb0.dll");
     if (hDll != NULL) 
 	{
-		result = 1;
+		ret = 0;
         FreeLibrary(hDll);
 	}
 
-    ticables_info("TiglUsb driver%sfound.", result ? " " : " not ");
-	if(!result)
-		ticables_info("TiglUsb support will be unavailable...");
-	
-	return result;
+    ticables_info("libusb-win32 driver%sfound.", ret ? " not ": " ");
+	return ret;
 }
