@@ -1,5 +1,5 @@
 /* Hey EMACS -*- win32-c -*- */
-/* $Id: ioports.c 3053 2006-11-06 17:08:45Z roms $ */
+/* $Id: ioports.c 3721 2007-08-24 21:22:35Z roms $ */
 
 /*  libticables2 - link cable library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Livin
@@ -34,19 +34,18 @@
 
 #include <stdio.h>
 #include <windows.h>
-#include <process.h>		// getpid
-#include <winioctl.h>		// PortTalk
-#include "porttalk_ioctl.h"	// PortTalk
 
 #include "../error.h"
 #include "../logging.h"
 #include "detect.h"
 #include "ioports.h"
 
+#include "../win32/dha.h"
+#include "../win64/rwp.h"
+
 /* Variables */
 
-static HINSTANCE hDll = NULL;	// Handle for PortTalk Driver
-static int instance = 0;		// Instance counter
+static int instance = 0;					// Instance counter
 
 /* Function pointers */
 
@@ -75,7 +74,7 @@ static void print_last_error(char *s)
 
 /* I/O thru assembly code */
 
-static int win32_asm_read_io(unsigned int addr)
+static int win32_read_io(unsigned int addr)
 {
         int c;
 
@@ -92,7 +91,7 @@ asm("movl $0,%%eax \n movw %1,%%dx \n inb %%dx,%%al \n movl %%eax,%0": "=g"(c):
         return c;
 }
 
-static void win32_asm_write_io(unsigned int addr, int data)
+static void win32_write_io(unsigned int addr, int data)
 {
 #ifdef __GNUC__
 asm("movw %0,%%dx \n movw %1,%%ax \n outb %%al,%%dx"::"g"(addr), "g"(data):"ax",
@@ -105,82 +104,87 @@ asm("movw %0,%%dx \n movw %1,%%ax \n outb %%al,%%dx"::"g"(addr), "g"(data):"ax",
 #endif
 }
 
+/* I/O thru device driver IOCTL calls */
+
+#ifdef _WIN64
+static int win64_read_io(unsigned int addr)
+{
+	unsigned char data;
+
+	rwp_read_byte((unsigned short)addr, &data);
+	return data;
+}
+
+static void win64_write_io(unsigned int addr, int data)
+{
+	rwp_write_byte((unsigned short)addr, (unsigned char)data);
+}
+#endif
+
 /* Functions used for initializing the I/O routines */
 
 int io_open(unsigned long from)
 {
-	DWORD BytesReturned;	// Bytes Returned for DeviceIoControl()
-	int offset;				// Offset for IOPM
-	int iError;				// Error Handling for DeviceIoControl()
-	DWORD pid;				// PID of the program which use the library
+	int ret;
 
-	io_rd = win32_asm_read_io;
-    io_wr = win32_asm_write_io;
-  
-	if(win32_detect_os() == WIN_NT)
+	if(win32_check_os() == WIN_9X)
 	{
-		// At this point, the driver should have been installed 
-		// and started in probe.c
-		hDll = CreateFile("\\\\.\\PortTalk",
-		      GENERIC_READ,
-		      0, NULL, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, NULL);
+		io_rd = win32_read_io;
+		io_wr = win32_write_io;
+	}
+#ifndef _WIN64
+	else if(win32_check_os() == WIN_NT)
+	{
+		ret = dha_enable();
+		if(ret) return ERR_DHA_NOT_FOUND;
 
-		if (hDll == INVALID_HANDLE_VALUE) 
-		{
-			ticables_info("couldn't access PortTalk Driver, Please ensure driver is installed/loaded.");
-			return ERR_PORTTALK_NOT_FOUND;
-		}
+		io_rd = win32_read_io;
+		io_wr = win32_write_io;
 
 		instance++;
-
-		// Turn off all access
-		iError = DeviceIoControl(hDll,
-					 IOCTL_IOPM_RESTRICT_ALL_ACCESS,
-					 NULL, 0, NULL, 0, &BytesReturned, NULL);
-
-		if (!iError)
-		  print_last_error("PortTalk: error %d occured in IOCTL_IOPM_RESTRICT_ALL_ACCESS");
-
-		// Turn on some access
-		offset = from / 8;
-		iError = DeviceIoControl(hDll,
-					 IOCTL_SET_IOPM,
-					 &offset, 3, NULL, 0, &BytesReturned, NULL);
-		if (!iError)
-		  print_last_error("Granting access");
-		else
-		  ticables_info("Address 0x%03X (IOPM Offset 0x%02X) has been granted access.",
-			  from, offset);
-
-		// Pass PID
-		pid = getpid();
-
-		iError = DeviceIoControl(hDll,
-					 IOCTL_ENABLE_IOPM_ON_PROCESSID,
-					 &pid, 4, NULL, 0, &BytesReturned, NULL);
-
-		if (!iError)
-		  print_last_error("Talking to device driver");
-		else
-		  ticables_info("PortTalk Device Driver has set IOPM for ProcessID %d.",
-			  pid);
-
 	}
+#else
+	else if(win32_check_os() == WIN_64)
+	{
+		ret = rwp_open();
+		if(ret) return ERR_DHA_NOT_FOUND;
+
+		io_rd = win64_read_io;
+		io_wr = win64_write_io;
+
+		instance++;
+	}
+#endif
 
   return 0;
 }
 
 int io_close(unsigned long from)
 {
-	if(win32_detect_os() == WIN_NT)
+	int ret;
+
+	if(0) {}
+#ifndef _WIN64
+	else if(win32_check_os() == WIN_NT)
 	{
 		instance--;
 		if(!instance)
 		{
-			CloseHandle(hDll);
-			hDll = INVALID_HANDLE_VALUE;
+			ret = dha_disable();
+			if(ret) return ERR_DHA_NOT_FOUND;
 		}
 	}
+#else
+	else if(win32_check_os() == WIN_64)
+	{
+		instance--;
+		if(!instance)
+		{
+			ret = rwp_close();
+			if(ret) return ERR_DHA_NOT_FOUND;
+		}
+	}
+#endif
 
 	return 0;
 }
