@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: link_par.c 3053 2006-11-06 17:08:45Z roms $ */
+/* $Id: link_par.c 3720 2007-08-24 20:57:50Z roms $ */
 
 /*  libticables2 - link cable library, a part of the TiLP project
  *  Copyright (C) 1999-2005  Romain Lievin
@@ -44,12 +44,20 @@ static int par_prepare(CableHandle *h)
 	default: return ERR_ILLEGAL_ARG;
 	}
 
-	if(win32_detect_os() == WIN_NT)
+	if(win32_check_os() == WIN_NT)
 	{
-		if(!win32_detect_porttalk())
+		if(!win32_check_dha())
 		{
 			free(h->device); h->device = NULL;
-			return ERR_PORTTALK_NOT_FOUND;
+			return ERR_DHA_NOT_FOUND;
+		}
+	}
+	else if(win32_check_os() == WIN_64)
+	{
+		if(!win32_check_rwp())
+		{
+			free(h->device); h->device = NULL;
+			return ERR_DHA_NOT_FOUND;
 		}
 	}
 
@@ -60,10 +68,7 @@ static int par_reset(CableHandle *h);
 static int par_open(CableHandle *h)
 {
 	TRYC(io_open(h->address));
-#ifdef __WIN32__
-	// needed for circumventing a strange problem with PortTalk & Win2k
-  	TRYC(io_open(h->address))
-#endif
+
   	io_wr(lpt_ctl, io_rd(lpt_ctl) & ~0x20);	// ouput mode only
 	
 	TRYC(par_reset(h));
